Index: webrtc/api/objc/RTCVideoSource+Private.h |
diff --git a/webrtc/api/objc/RTCVideoSource+Private.h b/webrtc/api/objc/RTCVideoSource+Private.h |
index c363d3390e5378d16e5a009bfe59ed13d7ff65de..be064bdd9b0e176674173b7272a2c701a63b8fa7 100644 |
--- a/webrtc/api/objc/RTCVideoSource+Private.h |
+++ b/webrtc/api/objc/RTCVideoSource+Private.h |
@@ -17,15 +17,16 @@ NS_ASSUME_NONNULL_BEGIN |
@interface RTCVideoSource () |
/** |
* The VideoSourceInterface object passed to this RTCVideoSource during |
* construction. |
*/ |
@property(nonatomic, readonly) |
- rtc::scoped_refptr<webrtc::VideoSourceInterface> nativeVideoSource; |
+ rtc::scoped_refptr<webrtc::VideoTrackSourceInterface> |
+ nativeVideoSource; |
-/** Initialize an RTCVideoSource from a native VideoSourceInterface. */ |
+/** Initialize an RTCVideoSource from a native VideoTrackSourceInterface. */ |
- (instancetype)initWithNativeVideoSource: |
- (rtc::scoped_refptr<webrtc::VideoSourceInterface>)nativeVideoSource |
+ (rtc::scoped_refptr<webrtc::VideoTrackSourceInterface>)nativeVideoSource |
NS_DESIGNATED_INITIALIZER; |
+ (webrtc::MediaSourceInterface::SourceState)nativeSourceStateForState: |
@@ -17,15 +17,16 @@ NS_ASSUME_NONNULL_BEGIN |
/** |
- * The VideoSourceInterface object passed to this RTCVideoSource during |
+ * The VideoTrackSourceInterface object passed to this RTCVideoSource during |
* construction. |
*/ |